==> deepin-font-manager_5.8.0.13.orig.tar.xz: deepin-font-manager-5.8.0.13/translations/deepin-font-manager_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Tüm Yazı Tipleri</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Kullanıcı</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Sık kullanılanlar</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktif</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Çince</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Eşit aralıklı</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Bozuk dosya</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Aynı sürüm kurulu</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Sistem Yazı Tipi</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Yazı tipleri</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 yazı tipi kurulu</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 yazı tipi kurulu</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete this font?</source>
        <translation>Bu yazı tipini silmek istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Bu yazı tipi uygulamalar tarafından kullanılamayacak</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Bu yazı tipleri uygulamalar tarafından kullanılamaz</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Diğer %1 sistem yazı tipleri silinemez</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Kullanımdaki &quot;%1&quot; yazı tipi silinemiyor</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Diğer %1 sistem yazı tipleri ve kullanımdaki &quot;%2&quot; yazı tipi silinemiyor</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>%1 yazı tipini silmek istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Yazı tipleri siliniyor, lütfen bekleyin...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Yazı Tipi Doğrulaması</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Devam</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Kurulacak yazı tipi yok</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Hayallerinin rüya olmasına izin verme</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Temel bilgi</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Tip</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tür</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Açıklama</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Bilinmeyen</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Tam isim</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps ismi</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Marka</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Yazı Tipi Yöneticisi</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Yazı Tipi Yöneticisi, kullanıcıların yazı tiplerini kurmasına ve yönetmesine yardımcı olur.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Yazı tipleri yükleniyor, lütfen bekleyin...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Masaüstünüze dışa aktarılan yazı tipi</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 yazı tipi masaüstünüze dışa aktarıldı</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>1 yazı tipi dışa aktarılamadı. Yeterli disk alanı yok.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>%1 yazı tipi dışa aktarılamadı. Yeterli disk alanı yok.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Yazı tipi ekle</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Etkinleştir</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Devre dışı</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sık kullanılan</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sık kullanılandan çıkar</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Ayrıtılar</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Dosya yöneticisinde görüntüle</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Dışarı aktar</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>devre dışı</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Yazı tipleri devre dışı bırakıldı</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 kullanımda, devre dışı bırakamazsınız</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Sistem yazı tiplerini ve kullanılanları devre dışı bırakamazsınız</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Sistem yazı tiplerini devre dışı bırakamazsınız</translation>
    </message>
    <message>
        <source>Some fonts are not allowed to be disabled</source>
        <translation>Bazı yazı tipleri devre dışı bırakılamıyor</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Yazı Tipi Kur</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Doğrulanıyor...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Bilinmeyen</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Bozuk dosya</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Kurulu</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Kurulu Değil</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Yazı Tipi Kur</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Arama sonucu bulunamadı</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Yazı tipi yok</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Kısayolları görüntüle</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Yukarı</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Aşağı</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Yazı tipi ekle</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sık kullanılan</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sık kullanılandan çıkar</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Yazı tipi bilgisi</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Önizleme metni gir</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Bozuk dosya</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Tüm Yazı Tipleri</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Kullanıcı</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Sık kullanılanlar</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktif</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Çince</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Eşit aralıklı</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 bir yazı tipi ailesi, devam ederseniz, içindeki tüm yazı tipleri silinecek</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Sil</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 bir yazı tipi ailesi, devam ederseniz, içindeki tüm yazı tipleri etkinleştirilecek</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 bir yazı tipi ailesi, devam ederseniz, içindeki tüm yazı tipleri devre dışı bırakılacak</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Etkinleştir</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Devre dışı</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Tüm seçili yazı tipi ailelerine uygula</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Bozuk dosya</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Aynı sürüm kurulu</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Sistem Yazı Tipi</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 yazı tipi kurulu</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 yazı tipi kurulu</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>%1 yazı tipi kurulamadı. Yeterli disk alanı yok.</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>%1 yazı tipi kurulamadı. Yeterli disk alanı yok.</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Bu yazı tipi uygulamalar tarafından kullanılamayacak</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Bu yazı tipleri uygulamalar tarafından kullanılamaz</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Diğer %1 sistem yazı tipleri silinemez</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Kullanımdaki &quot;%1&quot; yazı tipi silinemiyor</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Diğer %1 sistem yazı tipleri ve kullanımdaki &quot;%2&quot; yazı tipi silinemiyor</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>%1 yazı tipini silmek istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Sil</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Yazı tipleri siliniyor, lütfen bekleyin...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Yazı Tipi Doğrulaması</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Kurulacak yazı tipi yok</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Çıkış</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Devam</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Temel bilgi</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Tip</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tür</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Açıklama</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Bilinmeyen</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Tam isim</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps ismi</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Marka</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Yazı Tipi Yöneticisi</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Yazı Tipi Yöneticisi, kullanıcıların yazı tiplerini kurmasına ve yönetmesine yardımcı olur.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Yazı tipleri yükleniyor, lütfen bekleyin...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Masaüstünüze dışa aktarılan yazı tipi</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 yazı tipi masaüstünüze dışa aktarıldı</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>1 yazı tipi dışa aktarılamadı. Yeterli disk alanı yok.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>%1 yazı tipi dışa aktarılamadı. Yeterli disk alanı yok.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Yazı tipi ekle</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Etkinleştir</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Devre dışı</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sık kullanılan</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sık kullanılandan çıkar</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Ayrıtılar</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Dosya yöneticisinde görüntüle</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Dışarı aktar</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>devre dışı</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Yazı tipleri devre dışı bırakıldı</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 kullanımda, devre dışı bırakamazsınız</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Sistem yazı tiplerini ve kullanılanları devre dışı bırakamazsınız</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Sistem yazı tiplerini devre dışı bırakamazsınız</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Yazı Tipi Kur</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Doğrulanıyor...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Bilinmeyen</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Bozuk dosya</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Kurulu</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Kurulu Değil</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Yazı Tipi Kur</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Arama sonucu bulunamadı</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Yazı tipi yok</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Kısayolları görüntüle</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Yukarı</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Aşağı</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Yazı tipi ekle</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sık kullanılan</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sık kullanılandan çıkar</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Yazı tipi bilgisi</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Önizleme metni gir</translation>
    </message>
</context>
</TS>
